"""
Extension for the `test` cog.
Loading this file via `commands.Bot.load_extension` will add the `test` cog to the bot.
"""

import logging

import textwrap
from markdownify import markdownify
from discord import app_commands, Interaction, Embed
from discord.ext import commands, tasks
from sqlalchemy import insert, select

from db import DatabaseManager, AuditModel
from feed import Feeds, get_source

log = logging.getLogger(__name__)


class Test(commands.Cog):
    """
    News cog.
    Delivers embeds of news articles to discord channels.
    """

    def __init__(self, bot):
        super().__init__()
        self.bot = bot

    @commands.Cog.listener()
    async def on_ready(self):
        log.info(f"{self.__class__.__name__} cog is ready")

    @app_commands.command(name="test-latest-article")
    # @app_commands.choices(source=[
    #     app_commands.Choice(name="The Babylon Bee", value=Feeds.THE_BABYLON_BEE),
    #     app_commands.Choice(name="The Upper Lip", value=Feeds.THE_UPPER_LIP),
    #     app_commands.Choice(name="BBC News", value=Feeds.BBC_NEWS),
    # ])
    async def test_bee(self, inter: Interaction, source: Feeds):

        await inter.response.defer()
        await self.bot.audit("Requesting latest article.", inter.user.id)

        source = get_source(source)
        article = source.get_latest_article()

        md_description = markdownify(article.description, strip=("img",))
        article_description = textwrap.shorten(md_description, 4096)

        embed = Embed(
            title=article.title,
            description=article_description,
            url=article.url,
            timestamp=article.published,
        )
        embed.set_thumbnail(url=source.icon_url)
        embed.set_image(url=await article.get_thumbnail_url())
        embed.set_footer(text=article.author)
        embed.set_author(
            name=source.name,
            url=source.url,
        )

        log.debug(article)
        log.debug(article_description)

        await inter.followup.send(embed=embed)





async def setup(bot):
    """
    Setup function for this extension.
    Adds the `ErrorCog` cog to the bot.
    """

    cog = Test(bot)
    await bot.add_cog(cog)
    log.info(f"Added {cog.__class__.__name__} cog")
